Learn R Programming

splusTimeSeries (version 1.5.0-73)

positions: Positions of series Objects

Description

Accesses the positions of series objects.

Usage

positions(object)
positions(object) <- value

Arguments

object
the object for which to find positions.
value
the value to which to set the positions.

Value

  • returns the positions slot of object.

Details

This function can also be used on the left side of an assignment to set the positions of a series object.

See Also

seriesData, timeSeries, signalSeries.

Examples

Run this code
x <- signalSeries(pos=1:10, data=11:20) 
positions(x) 
positions(x) <- 11:20

Run the code above in your browser using DataLab