Learn R Programming

splusTimeSeries (version 1.5.0-73)

series-class: Base Class for Time Series and Signals

Description

A base class representing ordered data objects, such as time series and signals, that have positions (x values, times), and for each position a set of variables (stored in any rectangular data object).

Arguments

Series functions

  • Theseriesclass has a validity function,seriesValid.
  • The access functionspositionsandseriesDatacan access the positions and data in the object, and they can be used on the left side of assignments.
  • There are also methods defined forseriesobjects for the following functions:
    • nrow
    • ncol
    • start
    • end
    • subscripting
    • the standard rectangular data functions (seeis.rectangular)
    • basic arithmetic.

Details

The series class holds x positions and variable data. It is valid only when the lengths of the positions and data match, and when the data slot is a rectangular object.

seriesVirtual is a virtual class corresponding to series. All of the methods for series objects are defined on the corresponding virtual seriesVirtual class so they can be inherited easily by extending classes.

series has two built-in extending classes: timeSeries and signalSeries. series is not meant to be used directly. Instead, most users should use the signalSeries and timeSeries classes. Extending classes should include both series and seriesVirtual in their representations.

See Also

timeSeries class, signalSeries class, is.rectangular.