Learn R Programming

splusTimeSeries (version 1.5.0-73)

signalSeries-class: signalSeries Class

Description

Represents non-calendar time series and signal objects.

Arguments

signalSeries functions

You can create objects of class signalSeries using the new function, in which case they are set up to be empty. Alternatively, you can create objects of class signalSeries using the signalSeries function.

These objects can be subscripted and used in mathematical operations much like data frames or matrices.

Details

The signalSeries class inherits from the series and seriesVirtualclasses. It has slots that hold x positions and variable data inherited from the series class.

A signalSeries object is valid only when the lengths of the positions and data match, the data is a rectangular object, and the positions slot holds a positionsNumeric object.

See Also

series class, signalSeries, is.rectangular.