Learn R Programming

splusTimeSeries (version 1.5.0-73)

tcm.curve: Treasury Constant Maturity Curve

Description

Treasury Constant Maturity Curve data running from 1982 to 1997. The Constant Maturity Curve data come from yield curves constructed by the U.S. Treasury Department from the yields of actively traded issues adjusted to constant maturities.

Arguments

source

From the web site of the Federal Reserve Bank, http://www.bog.frb.fed.us/releases/H15/data.htm.