seriesclass has a validity function,seriesValid.positionsandseriesDatacan access the positions and data in the object, and they can be used
on the left side of assignments.seriesobjects for the
following functions:nrowncolstartendis.rectangular)series class holds x positions and variable data.
It is valid only when the lengths of the positions and data match,
and when the data slot is a rectangular object. seriesVirtual is a virtual class
corresponding to series. All of the methods
for series objects are defined on the corresponding virtual
seriesVirtual class so they can be inherited easily
by extending classes.
series has two built-in extending classes:
timeSeries and signalSeries. series is not meant to be used directly. Instead, most users should use the
signalSeries and timeSeries classes. Extending classes
should include both series and seriesVirtual in their representations.
timeSeries class, signalSeries class, is.rectangular.