signalSeries using the new function, in
which case they are set up to be empty. Alternatively, you can create objects
of class signalSeries using the signalSeries function. These objects can be subscripted and used in mathematical operations much like data frames or matrices.
signalSeries class inherits from the series
and seriesVirtualclasses. It has slots that hold x positions and variable data
inherited from the series class. A signalSeries object is valid only when the lengths of the positions and data match, the data is a rectangular object,
and the positions slot holds a positionsNumeric object.
series class, signalSeries , is.rectangular.