timeSeries using the
new function, in which case they are set up to be empty
and have their fiscal year starting in January. Alternatively, you
can create objects of class timeSeries using the timeSeries
function. These can be subscripted and used in mathematical operations much like data frames or matrices.
timeSeries class inherits series and seriesVirtual.
From series, it inherits slots that hold x positions and variable data.
A timeSeries object is valid only when the lengths of the positions and
data match, the data slot is rectangular,
and the positions slot holds a positionsCalendar object.series class, timeSeries,
is.rectangular.